@@ -11,7 +11,7 @@ pub use {
 	index::{Index, IndexFilter},
 	join::{join_iters, JoinType},
 	row::{Row, RowError},
-	schema::Schema,
+	schema::*,
 	table::{get_name, Table, TableError},
 	value::*,
 };
