@@ -1,6 +1,4 @@
 mod alter_table;
-mod create_index;
-mod create_table;
 mod drop;
 mod error;
 mod truncate;
