@@ -1,8 +1,8 @@
 crate::util_macros::testcase!(
 	(|mut glue: multisql::Glue| {
 		crate::util_macros::make_basic_table!(glue);
-		glue.execute(r#"
+		crate::util_macros::assert_success!(glue, r#"
 			CREATE INDEX index ON basic (a);
-		"#).expect("CREATE INDEX basic_index");
+		"#);
 	})
 );
