@@ -1,27 +1,42 @@
 crate::util_macros::testcase!(
 	(|mut glue: multisql::Glue| {
-		crate::util_macros::assert_success!(glue, "
+		crate::util_macros::assert_success!(
+			glue,
+			"
 			CREATE TABLE simple (
 				id INTEGER,
 				val FLOAT
 			)
-		");
+		"
+		);
 
-		crate::util_macros::assert_success!(glue, "
+		crate::util_macros::assert_success!(
+			glue,
+			"
 			EXPLAIN simple
-		");
+		"
+		);
 
-		crate::util_macros::assert_success!(glue, "
+		crate::util_macros::assert_success!(
+			glue,
+			"
 			EXPLAIN main
-		");
+		"
+		);
 
-		crate::util_macros::assert_success!(glue, "
+		crate::util_macros::assert_success!(
+			glue,
+			"
 			EXPLAIN main.simple
-		");
+		"
+		);
 
-		crate::util_macros::assert_error!(glue, "
+		crate::util_macros::assert_error!(
+			glue,
+			"
 			EXPLAIN nonsense
-		");
+		"
+		);
 
 		crate::util_macros::assert_select!(glue, "
 			EXPLAIN main
@@ -32,7 +47,7 @@ crate::util_macros::testcase!(
 		crate::util_macros::assert_select!(glue, "
 			EXPLAIN main.simple
 		" => column = Str, data_type = Str:
-			(String::from("id"), String::from("Signed Integer")),
+			(String::from("id"), String::from("Int")),
 			(String::from("val"), String::from("Float"))
 		);
 
